#!/bin/sh
##************************************************************
##
## Example script to handle a user-defined resource
##
## Script takes one parameter, namely the resource name
## specified in the SAS Workload Orchestrator configuration
##
##************************************************************

resName=$1

##************************************************************
##
## Do something different based on which resource this is
## being asked about
##
##************************************************************
case $resName in

    ##********************************************************
    ## "My Global Static" resource. This is called on the
    ## master when it becomes the master.
    ##
    ## In this example, assume the resource will be the number
    ## of licensed of some product that can be used anywhere
    ## on the grid. We are indicating there are 20 of these
    ## licenses that can be consumed by all jobs on all hosts
    ##********************************************************
    myGlobalStatic)
      echo "20.0"
      ;;

    ##********************************************************
    ## "My Host Static" resource. This is called on the host
    ## whenever it announces itself to the master or when the
    ##
    ## In this example, assume the resource will be the numer
    ## of GPUs available on this host. We are indicating there
    ## are 4 GPUs on this machine that can be consumed by all
    ## jobs routed to this host.
    ##********************************************************
    myHostStatic)
      echo "4.0"
      ;;

    ##********************************************************
    ## "My Host Dynamic" resource. This is called on the host
    ## periodically as defined by the hostUpdateSecs field in
    ## the configuration.
    ##
    ## In this example, assume the resource is the percent of
    ## used space in the SASWORK directory. We are going to
    ## return a value that will be able to be used for
    ## scheduling or suspend thresholds and for sort order.
    ##********************************************************
    myHostDynamic)
      echo `df /path/to/SASWORK | awk '$3 ~ /[0-9]+/ { print $4 }' | sed -e 's/%//'`
      ;;

    ##********************************************************
    ## Unknown resource. Return 0
    ##********************************************************
    *)
      echo "0.0"
      ;;
esac
