#!/bin/sh
##************************************************************
##
## Example script to handle a service
##
##************************************************************

action=$1

name="SampleService"
script=`basename "$0"`
now=`date +%Y-%m-%d@%H:%M:%S`
command="sleep 600"
thisHost=`hostname`
log_filename="/tmp/${name}.${thisHost}.log"
pid_filename="/tmp/${name}.${thisHost}.pid"

##************************************************************
##
## Define the functions to be used
##
##************************************************************

##**********************************************************
## Start the Service
##**********************************************************
start_service()
{
  if [ -f $pid_filename ]; then
     pid=`cat $pid_filename`
     kill -0 $pid > /dev/null 2>&1
     if [ $? -eq 0 ]; then
        echo "${now} ${script}: Service ${name} (pid $pid) is already running"
        exit 0
     fi
     rm $pid_filename
  fi
  nohup $command > $log_filename 2>&1 &
  pid=$!
  echo $pid > $pid_filename
  echo "${now} ${script}: Service ${name} (pid $pid) is started"
}

##**********************************************************
## Stop the Service
##**********************************************************
stop_service()
{
  if [ -f $pid_filename ]; then
    pid=`cat $pid_filename`
    kill $pid > /dev/null 2>&1
    if [ $? -ne 0 ]; then
      echo "${now} ${script}: Service ${name} (pid $pid) could not be stopped"
    else
      echo "${now} ${script}: Service ${name} (pid $pid) has been stopped"
      rm $pid_filename
    fi
  else
    echo "${now} ${script}: Service ${name} is stopped"
    exit 1
  fi
}

##**********************************************************
## Get the Service's status
##
##   status = 0, everything is OK
##   status < 0, temp error, retry 5 times before restarting
##   status > 0, error, try restarting
##**********************************************************
get_service_status()
{
  if [ -f $pid_filename ]; then
    pid=`cat $pid_filename`
    kill -0 $pid > /dev/null 2>&1
    if [ $? -ne 0 ]; then
      echo "${now} ${script}: Service ${name} (pid $pid) is stopped"
      exit 1
    else
      echo "${now} ${script}: Service ${name} (pid $pid) is running"
      exit 0
    fi
  else
    echo "${now} ${script}: Service ${name} is assumed to be stopped"
    exit 1
  fi
}




##************************************************************
##
## Perform the requested action
##
##************************************************************
case $action in

  ##**********************************************************
  ## Start the Service
  ##**********************************************************
  start | -start)
    start_service
    ;;

  ##**********************************************************
  ## Stop the Service
  ##**********************************************************
  stop | -stop)
    stop_service
    ;;

  ##**********************************************************
  ## Get the service's status
  ##**********************************************************
  status | -status)
    get_service_status
    ;;

  ##**********************************************************
  ## Restart the service
  ##**********************************************************
  restart | -restart)
    echo "${now} ${script}: Service ${name} is being restarted"
    stop_service
    sleep 1
    start_service
    ;;

  ##**********************************************************
  ## Unknown option
  ##**********************************************************
  *)
    echo "Invalid option \"$1\""
    echo "Usage: $SCRIPT {-}{start|stop|status|restart}"
    exit 1
esac

exit 0
